==> code-scan-complexity-0.0.1.tgz: package/lib/collectComplexity.js <==
const complexity = require("./complexity");
const scan = require("./scan");
const line = require("./line");

// 对于复杂度给出建议
const getAdvice = (complexity) => {
  if (complexity > 70) return "强烈建议";
  else if (complexity >= 60) return "建议";
  else return "无需";
};

/**
 *
 * @param {*} fileLines 行数详情
 * @param {*} fileComs 复杂度详情
 * @param {*} min 复杂度最小阈值
 */
const getComplexity = (codeLine, codeComplexity) => {
  return codeLine.map((fileLine) => {
    const fileDetail = [];
    let total = 0;
    let funcComplexity = 0;
    let baseComplexity = 0;
    const { allLine, importLine, commentLine, func, filePath } = fileLine;
    const funcCount = func.length;
    codeComplexity
      .filter((fileCom) => fileLine.filePath === fileCom.filePath)
      .forEach((fileCom) => {
        const funDetail = func.find((item) => item.funcLoc === fileCom.funcLoc);

        if (funDetail) {
          const { funcLine, funcParams } = funDetail;
          funcComplexity +=
            Math.floor(funcLine / 150) * 5 + Math.floor(funcParams / 5) * 5;
          baseComplexity += fileCom.complexity || 0;
          fileDetail.push({
            ...funDetail,
            ...fileCom,
          });
        } else {
          // ast 查找将对象添加到数组中，先吃掉这个错误
          // console.log(fileCom);
        }
      });
    total += Math.floor(allLine / 600) * 5 + Math.floor(funcCount / 15) * 5;
    total += importLine / 2;
    total += funcComplexity;
    total += baseComplexity;
    return {
      advice: getAdvice(total),
      complexity: total,
      baseComplexity,
      funcComplexity,
      importLine,
      commentLine,
      filePath,
      fileDetail,
    };
  });
};

/**
 *
 * @param {*} scanParam scan 文件扫描的参数
 */
module.exports = async function collectComplexity(scanParam = {}) {
  const files = scan(scanParam);
  const lines = line(files);
  const complexitys = await complexity(files);
  const { detail } = complexitys;
  const result = getComplexity(lines, detail);
  const fileDetail = result.map((item) => item.fileDetail).flat();
  const comDetail = result.map((item) => {
    delete item.fileDetail;
    return item;
  });
  return {
    complexitys,
    result: comDetail,
    fileDetail,
  };
};

==> code-scan-complexity-0.0.3.tgz: package/lib/collectComplexity.js <==
const complexity = require("./complexity");
const scan = require("./scan");
const line = require("./line");

// 对于复杂度给出建议
const getAdvice = (complexity) => {
  if (complexity > 70) return "强烈建议";
  else if (complexity >= 50) return "建议";
  else return "无需";
};

/**
 *
 * @param {*} fileLines 行数详情
 * @param {*} fileComs 复杂度详情
 * @param {*} min 复杂度最小阈值
 */
const getComplexity = (codeLine, codeComplexity) => {
  return codeLine.map((fileLine) => {
    const fileDetail = [];
    let total = 0;
    let funcComplexity = 0;
    let baseComplexity = 0;
    const { allLine, importLine, commentLine, func, filePath } = fileLine;
    const funcCount = func.length;
    codeComplexity
      .filter((fileCom) => fileLine.filePath === fileCom.filePath)
      .forEach((fileCom) => {
        const funDetail = func.find((item) => item.funcLoc === fileCom.funcLoc);
        console.log(funDetail);
        if (funDetail) {
          const { funcLine, funcParams } = funDetail;
          funcComplexity +=
            Math.floor(funcLine / 150) * 5 + Math.floor(funcParams / 5) * 5;
          baseComplexity += fileCom.complexity || 0;
          fileDetail.push({
            ...funDetail,
            ...fileCom,
          });
        } else {
          // ast 查找将对象添加到数组中，先吃掉这个错误
          console.log("fileCom------------------------我没匹配上啊", fileCom);
        }
      });
    total += Math.floor(allLine / 600) * 5 + Math.floor(funcCount / 15) * 5;
    total += importLine / 2;
    total += funcComplexity;
    total += baseComplexity;
    console.log(funcCount, fileDetail);

    return {
      advice: getAdvice(total),
      complexity: total,
      baseComplexity,
      funcComplexity,
      importLine,
      commentLine,
      filePath,
      fileDetail,
    };
  });
};

/**
 *
 * @param {*} scanParam scan 文件扫描的参数
 */
module.exports = async function collectComplexity(scanParam = {}) {
  const files = scan(scanParam);
  const lines = line(files);
  const complexitys = await complexity(files);
  const { detail } = complexitys;
  const result = getComplexity(lines, detail);
  const fileDetail = result.map((item) => item.fileDetail).flat();
  const commonDetail = result.map((item) => {
    delete item.fileDetail;
    return item;
  });
  return {
    complexitys,
    result: commonDetail,
    fileDetail,
  };
};
